@@ -3,9 +3,10 @@ from .blockmatch import *
 from .bm3d import *
 from .ccd import *
 from .deblock import *
-from .dfttest import *
+from .fft import *
 from .funcs import *
 from .knlm import *
+from .limit import *
 from .mvtools import *
 from .postprocess import *
 from .prefilters import *
